pub struct ByteLiteral;Expand description
An abstraction over a byte literal to provide a method to convert safely
to a c_char.
The abstraction is required so we can contain architecture specific code in a central location.
Implementations
Sourceimpl ByteLiteral
impl ByteLiteral
Sourcepub fn cast_cchar(input: u8) -> c_char
pub fn cast_cchar(input: u8) -> c_char
Casts a byte literal (u8) to a c_char without using as.
Panics
If input is not within the following range of ascii characters:
- Octal:
040..=176 - Decimal:
30..=126 - Hexadecimal:
20..=7E - Byte literals: The space character (
) upto and including tilde (~)